#
# SPDX-License-Identifier: GPL-2.0-only
#
use strict;
use warnings;

use lib './lib';

use Test::More;
use Test::Deep;

use Test::Mailmunge::Tmpdir;
use Test::Mailmunge::Utils;

my $t = Test::Mailmunge::Tmpdir->new();
my $d = $t->{dir};

start_multiplexor($d, 't/filters/test-filter.pl');

my $msg_dir = $d . '/mm-foobar';
mkdir($msg_dir, 0755);

my $ctx = parse_and_copy_msg($msg_dir, 't/data/generic-msg', 'addentity');

ok($ctx->mime_entity, 'Successfully parsed sample message');
$ctx->recipients(['<bar@example.com>', '<wug@example.com>']);
write_commands_file($msg_dir, $ctx);
my $ans = mm_mx_ctrl($d, 'scan', 'qIa12345', $msg_dir);
is($ans, 'ok', 'Filter succeeded');

ok(results_has_lines($msg_dir, 'C', 'F'),
   'Got expected lines in RESULTS');
like(`cat $msg_dir/RESULTS`, qr/Mmultipart\/mixed;%20boundary=%22/,
     "Content type was changed to multipart/mixed");
like(`cat $msg_dir/NEWBODY`, qr/A new entity, woop woop!/, 'New entity was added');

END: {
        stop_multiplexor($d);
}

done_testing;

1;
